@@ -30,6 +30,7 @@ class View(object):
     content_type_accepted: str
     restrict_content_type: bool = False
     action: str = ''
+    rule = None
 
     def __init__(self, collection=None):
         self.collection = collection
@@ -40,7 +41,10 @@ class View(object):
 
     @classmethod
     def url(cls, collection):
-        raise NotImplementedError
+        if cls.rule:
+            return cls.rule
+        else:
+            raise NotImplementedError
 
     def get_response_class(self) -> Response:
         """
